package com.bytesw.bytebot.model;

import com.fasterxml.jackson.annotation.JsonProperty;
import lombok.EqualsAndHashCode;
import lombok.Getter;
import lombok.Setter;
import lombok.ToString;
import org.springframework.format.annotation.DateTimeFormat;

import javax.persistence.*;
import java.io.Serializable;
import java.util.Date;
import java.util.List;

@Entity
@Table(name = "flight_schedules")
@Getter
@Setter
@EqualsAndHashCode
@ToString
public class FlightSchedule implements Serializable {
    @Id
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    private Long id;

    @Column(name = "airline_code")
    private String airlineCode;

    @Column(name = "usual_aircraft_type_code")
    private String codeTypeAircraft;

    @Column(name = "departure_date_time")
    @Temporal(TemporalType.TIMESTAMP)
    private Date departureDate;

    @Column(name = "arrival_date_time")
    @Temporal(TemporalType.TIMESTAMP)
    @DateTimeFormat(pattern = "yyyy-MM-dd")
    private Date arrivalDate;

    @ManyToOne(fetch = FetchType.LAZY, optional = false)
    @JoinColumn(name = "origin_airport_code")
    @JsonProperty(access = JsonProperty.Access.WRITE_ONLY)
    private Airport codeAirportOrigin;

    @ManyToOne(fetch = FetchType.LAZY, optional = false)
    @JoinColumn(name = "destination_airport_code")
    @JsonProperty(access = JsonProperty.Access.WRITE_ONLY)
    private Airport codeAirportDestination;

    @OneToMany(mappedBy = "codeFlight", cascade = CascadeType.ALL)
    private List<Leg> legs;

    @Column(name = "flight_cost")
    private double flightCost;

}
