package com.bytesw.bytebot.service;

import com.bytesw.bytebot.dto.AirportDto;
import com.bytesw.bytebot.dto.FlightDto;
import com.bytesw.bytebot.model.Airport;
import com.bytesw.bytebot.model.FlightSchedule;
import com.bytesw.bytebot.repository.IFlightRepository;
import com.bytesw.xdf.service.XDFService;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

@Service
@Transactional
public class FlightService extends XDFService<FlightSchedule, FlightDto, Long> {

    protected FlightService(IFlightRepository flightRepository) {
        super(flightRepository);
    }

    @Autowired
    private AirportService  airportService;

    @Override
    protected FlightSchedule toModel(FlightSchedule flightSchedule, FlightDto flightDto) {
        if(flightSchedule == null) {
            flightSchedule = new FlightSchedule();
        }

        BeanUtils.copyProperties(flightDto, flightSchedule);
        AirportDto airportDto = airportService.getById(flightDto.getCodeAirportOrigin());
        AirportDto airportDto1 = airportService.getById(flightDto.getCodeAirportDestination());

        flightSchedule.setCodeAirportOrigin(airportService.toModel(new Airport(), airportDto));
        flightSchedule.setCodeAirportDestination(airportService.toModel(new Airport(), airportDto1));

        return flightSchedule;
    }

    @Override
    protected FlightDto toBean(FlightSchedule flightSchedule) {
        FlightDto flightDto = new FlightDto();
        BeanUtils.copyProperties(flightSchedule, flightDto);
        flightDto.setCodeAirportOrigin(flightSchedule.getCodeAirportOrigin().getId());
        flightDto.setCodeAirportOrigin(flightSchedule.getCodeAirportDestination().getId());
        flightDto.setAirportOrigin(flightSchedule.getCodeAirportOrigin().getAirportCode());
        flightDto.setAirportDestination(flightSchedule.getCodeAirportDestination().getAirportCode());
        flightDto.setLegs(flightSchedule.getLegs());
        return flightDto;
    }
}
