package com.bytesw.bytebot.service;

import com.bytesw.bytebot.dto.BookingAgentDto;
import com.bytesw.bytebot.dto.ItineraryReservationDto;
import com.bytesw.bytebot.dto.PassengerDto;
import com.bytesw.bytebot.model.BookingAgent;
import com.bytesw.bytebot.model.ItineraryReservation;
import com.bytesw.bytebot.model.Passenger;
import com.bytesw.bytebot.repository.IItineraryReservationRepository;
import com.bytesw.xdf.service.XDFService;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

@Service
@Transactional
public class ItineraryReservationService extends XDFService<ItineraryReservation, ItineraryReservationDto, Long> {
    protected ItineraryReservationService(IItineraryReservationRepository repository) {
        super(repository);
    }

    @Autowired
    private PassengerService passengerService;

    @Autowired
    private BookingAgentService bookingAgentService;

    @Override
    protected ItineraryReservation toModel(ItineraryReservation itineraryReservation, ItineraryReservationDto itineraryReservationDto) {
        if (itineraryReservation == null) {
            itineraryReservation = new ItineraryReservation();
        }

        BeanUtils.copyProperties(itineraryReservationDto, itineraryReservation);
        PassengerDto passengerDto = passengerService.getById(itineraryReservationDto.getCodePassenger());
        BookingAgentDto bookingAgentDto = bookingAgentService.getById(itineraryReservationDto.getCodeAgent());

        itineraryReservation.setPassenger(passengerService.toModel(new Passenger(), passengerDto));
        itineraryReservation.setAgent(bookingAgentService.toModel(new BookingAgent(), bookingAgentDto));
        return itineraryReservation;
    }

    @Override
    protected ItineraryReservationDto toBean(ItineraryReservation model) {
        ItineraryReservationDto bean = new ItineraryReservationDto();
        BeanUtils.copyProperties(model, bean);
        bean.setCodePassenger(model.getPassenger().getId());
        bean.setCodeAgent(model.getAgent().getId());

        return bean;
    }
}
