package com.bytesw.bytebot.service;

import com.bytesw.bytebot.dto.AirportDto;
import com.bytesw.bytebot.dto.FlightDto;
import com.bytesw.bytebot.dto.LegDto;
import com.bytesw.bytebot.model.Airport;
import com.bytesw.bytebot.model.FlightSchedule;
import com.bytesw.bytebot.model.Leg;
import com.bytesw.bytebot.repository.ILegRepository;
import com.bytesw.xdf.service.XDFService;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

@Service
@Transactional
public class LegService extends XDFService<Leg, LegDto, Long> {
    protected LegService(ILegRepository legRepository) {
        super(legRepository);
    }

    @Autowired
    private FlightService flightService;

    @Autowired
    private  AirportService airportService;

    @Override
    protected Leg toModel(Leg leg, LegDto legDto) {
        if (leg == null)
            leg = new Leg();
        BeanUtils.copyProperties(legDto, leg);
        FlightDto flightDto = flightService.getById(legDto.getCodeFlight());
        leg.setCodeFlight(flightService.toModel(new FlightSchedule(), flightDto));
        AirportDto airportDto = airportService.getById(legDto.getCodeAirportOrigin());
        AirportDto airportDto1 = airportService.getById(legDto.getCodeAirportDestination());
        leg.setCodeAirportOrigin(airportService.toModel(new Airport(), airportDto));
        leg.setCodeAirportDestination(airportService.toModel(new Airport(), airportDto1));
        return leg;
    }

    @Override
    protected LegDto toBean(Leg leg) {
        LegDto legDto = new LegDto();
        BeanUtils.copyProperties(leg, legDto);
        legDto.setCodeAirportOrigin(leg.getCodeAirportOrigin().getId());
        legDto.setCodeAirportDestination(leg.getCodeAirportDestination().getId());
        legDto.setAirportOrigin(leg.getCodeAirportOrigin().getAirportCode());
        legDto.setAirportDestination(leg.getCodeAirportDestination().getAirportCode());
        return legDto;
    }
}
